﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Windows.Input;
using Telerik.Windows.Controls;

namespace ChangeBrowsableRuntime
{
    public class MyViewModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        private ObservableCollection<Club> clubs;
        private ObservableCollection<Player> players;
        private object selectedItem;
        public ICommand ChangeBrowsableCommand { get; set; }

        public bool ShowStadiumCapacity
        {
            get { return this.Club.ShowStadiumCapacity; }
        }

        public MyViewModel()
        {
            this.Club.PropertyChanged += Club_PropertyChanged;
            this.ChangeBrowsableCommand = new DelegateCommand(OnChangeBrowsableCommandExecuted);
        }

        private void Club_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            if (e.PropertyName == "ShowStadiumCapacity")
            {
                this.OnPropertyChanged("ShowStadiumCapacity");
            }
        }

        private void OnChangeBrowsableCommandExecuted(object obj)
        {
            var propertyGrid = obj as RadPropertyGrid;
            var item = propertyGrid.Item as Club;
            item.ModifyBrowsableAttributeOfProperty("Name", true);
            propertyGrid.ReloadData();
        }

        public Club Club
        {
            get { return this.Clubs[0]; }
        }

        public ObservableCollection<Club> Clubs
        {
            get
            {
                if (this.clubs == null)
                {
                    this.clubs = Club.GetClubs();
                }

                return this.clubs;
            }
        }

        public ObservableCollection<Player> Players
        {
            get
            {
                if (this.players == null)
                {
                    this.players = Player.GetPlayers();
                }

                return this.players;
            }
        }

        public object SelectedItem
        {
            get { return this.selectedItem; }
            set
            {
                if (value != this.selectedItem)
                {
                    this.selectedItem = value;
                    this.OnPropertyChanged("SelectedItem");
                }
            }
        }

        protected virtual void OnPropertyChanged(PropertyChangedEventArgs args)
        {
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null)
            {
                handler(this, args);
            }
        }

        private void OnPropertyChanged(string propertyName)
        {
            this.OnPropertyChanged(new PropertyChangedEventArgs(propertyName));
        }
    }
}
